@@ -2,18 +2,34 @@ package YATT::Lite::Error; sub Error () {__PACKAGE__}
 use strict;
 use warnings FATAL => qw(all);
 use parent qw(YATT::Lite::Object);
+use constant DEBUG_VERBOSE => $ENV{YATT_DEBUG_VERBOSE};
 
 use YATT::Lite::MFields qw/cf_file cf_line cf_tmpl_file cf_tmpl_line
 	      cf_backtrace
 	      cf_reason cf_format cf_args/;
-use overload qw("" message);
+use overload qw("" message
+		eq streq
+		bool has_error
+	      );
 use YATT::Lite::Util qw(lexpand untaint_any);
 use Carp;
 require Scalar::Util;
 
+sub has_error {
+  defined $_[0];
+}
+
+sub streq {
+  my ($obj, $other, $inv) = @_;
+  ($obj, $other) = ($other, $obj) if $inv;
+  $obj->message eq $other;
+}
+
 sub message {
   my Error $error = shift;
-  $error->reason . $error->place;
+  my $msg = $error->reason . $error->place;
+  $msg .= $error->{cf_backtrace} // '' if DEBUG_VERBOSE;
+  $msg;
 }
 
 sub reason {
