@@ -67,6 +67,8 @@ use YATT::Lite::Util qw/lexpand globref untaint_any ckrequire dofile_in
 			lookup_path
 			secure_text_plain
 			psgi_error
+			globref_default
+			define_const
 		       /;
 
 use YATT::Lite::XHF ();
@@ -238,6 +240,7 @@ sub init_app_ns {
 sub after_new {
   (my MY $self) = @_;
   $self->SUPER::after_new;
+  $self->{cf_index_name} //= $self->default_index_name;
   $self->{cf_output_encoding} //= $self->default_output_encoding;
   $self->{cf_header_charset} //= (
     $self->{cf_output_encoding} || $self->default_header_charset
@@ -246,6 +249,7 @@ sub after_new {
 
 sub default_output_encoding { '' }
 sub default_header_charset  { 'utf-8' }
+sub default_index_name { 'index' }
 
 sub _after_after_new {
   (my MY $self) = @_;
@@ -525,7 +529,14 @@ sub buildns {
   # instns には MY を定義しておく。
   my $my = globref($newns, 'MY');
   unless (*{$my}{CODE}) {
-    *$my = sub () { $newns };
+    define_const($my, $newns);
+  }
+
+  # もし $newns の EntNS が Factory(SiteApp, app.psgi) の EntNS を継承していない
+  # なら、継承する
+  unless ($newns->EntNS->isa($self->EntNS)) {
+    push @{globref_default(globref($newns->EntNS, 'ISA')
+			   , [])}, $self->EntNS;
   }
 
   $newns;
@@ -539,6 +550,7 @@ sub _cf_delegates {
      at_done
      app_root
      namespace
+     index_name
      only_parse);
 }
 
